%% FiPIt: A Simple, Fast Global Method for Solving Models with Two
%% Endogenous States & Occasionally Binding Constraints
%% Mendoza & Villalvazo 2018
% Code for Computing Time-Series Simulation
% (C.) Enrique G. Mendoza & Sergio Villalvazo, 2018

%% SIMULATION PROCEDURE

clear all
close all
clc

tMyDir      = pwd;
tIdcs       = strfind(tMyDir,'\');
tMyDirUp    = tMyDir(1:tIdcs(end)-1);
tMFilesPath = [tMyDirUp, '\MFiles\'];
addpath(tMFilesPath);

load 'solFiPIt_SS.mat'

nTime = 1000000;    
nCut  = 10000;

nInitIdBond        = size(vBondGrid,1);
nInitIdCapital     = size(vCapitalGrid,1);
nInitialBond       = vBondGrid(1);
nInitialCapital    = vCapitalGrid(end);
[~,nInitIdCapital] = min(abs(nInitialCapital - vCapitalGrid));
[~,nInitIdBond]    = min(abs(nInitialBond - vBondGrid));
simCCBindInter  = zeros(nTime,1);
simCCBind  = zeros(nTime,1);
rng(1234);
[vStateIndex] = fMarkov(mTran,nTime+1,1,1:length(mTran));
for iTime = 1:nTime
    
    if iTime == 1
        simL(iTime,1) = mL(nInitIdBond,nInitIdCapital,vStateIndex(iTime));
        simV(iTime,1) = mV(nInitIdBond,nInitIdCapital,vStateIndex(iTime));
        
        simQK(iTime,1) = mPriceK(nInitIdBond,nInitIdCapital,vStateIndex(iTime));
        simKp(iTime,1) = nInitialCapital/pAdjC*(simQK(iTime,1) - 1 + pAdjC) ; 
        simBp(iTime,1) = mBondPrime(nInitIdBond,nInitIdCapital,vStateIndex(iTime)) ; 
        
        simW(iTime,1)   = simL(iTime,1)^(pOmega-1)*(1+pTaxCons);
        simTFP(iTime,1) = vProdGrid(vStateIndex(iTime));
        simP(iTime,1)   = vPriceGrid(vStateIndex(iTime));
        simR(iTime,1)   = vIntRateGrid(vStateIndex(iTime)) + 1;
        simQb(iTime,1)  = 1/simR(iTime,1);
        simGDP(iTime,1) = vProdGrid(vStateIndex(iTime))*nProd*nInitialCapital^pGamma*simL(iTime,1)^pAlpha*simV(iTime,1)^pEta - simP(iTime,1)*simV(iTime,1);
        
        simCons(iTime,1) = (-simKp(iTime,1) + (1-pDelta)*nInitialCapital - pAdjC/2*(simKp(iTime,1)-nInitialCapital)^2/nInitialCapital +...
            simGDP(iTime,1) - pPhi*(simR(iTime,1)-1)*...
            (simW(iTime,1)*simL(iTime,1) + simP(iTime,1)*simV(iTime,1)) - simQb(iTime,1)*simBp(iTime,1) + nInitialBond) / (1+pTaxCons);
        
        simNX(iTime,1) = -nInitialBond + simBp(iTime,1)/(1+vIntRateGrid(vStateIndex(iTime))) + vIntRateGrid(vStateIndex(iTime))*pPhi*(simW(iTime,1)*simL(iTime,1) + simP(iTime,1)*simV(iTime,1)) ;
        
        simInv(iTime,1) = simKp(iTime,1) - (1-pDelta)*nInitialCapital + pAdjC/2*( simKp(iTime,1) - nInitialCapital )^2/nInitialCapital;
        simB_Y(iTime,1) = nInitialBond / simGDP(iTime,1);
        simMu(iTime,1)  = mMu(nInitIdBond, nInitIdCapital, vStateIndex(iTime));
        simWC(iTime,1)  = pPhi*(simW(iTime,1)*simL(iTime,1) + simP(iTime,1)*simV(iTime,1));
        simLev(iTime,1) = (simQb(iTime,1)*simBp(iTime,1) - pPhi*simR(iTime,1)*(simW(iTime,1)*simL(iTime,1) + simP(iTime,1)*simV(iTime,1)))/(simQK(iTime,1)*simKp(iTime,1));
        
    else
        
        % Interpolation Procedure
        kX = simKp(iTime-1);
        bX = simBp(iTime-1);
        ikA = find(simKp(iTime-1) >= vCapitalGrid,1,'last');
        ibA = find(simBp(iTime-1) >= vBondGrid,1,'last');            
        if isempty(ikA) == 1 
            ikA = 1;                  
        end
        if isempty(ibA) == 1
            ibA = 1;                
        end
        if ikA == nCapitalGrid
            ikA = nCapitalGrid-1;               
        end
        if ibA == nBondGrid
            ibA = nBondGrid-1;               
        end

        kA = vCapitalGrid(ikA);
        kB = vCapitalGrid(ikA+1);

        bA = vBondGrid(ibA);
        bC = vBondGrid(ibA+1);

        fA = mPriceK(ibA,ikA,vStateIndex(iTime));
        fB = mPriceK(ibA,ikA+1,vStateIndex(iTime));
        fC = mPriceK(ibA+1,ikA,vStateIndex(iTime));
        fD = mPriceK(ibA+1,ikA+1,vStateIndex(iTime));

        simQK(iTime,1) = fBiLinearInterpolation(kA, kB, bA, bC, fA, fB, fC, fD, kX, bX);
        simKp(iTime,1) = simKp(iTime-1,1)/pAdjC*(simQK(iTime,1) - 1 + pAdjC) ; 
               
        fA = mBondPrime(ibA,ikA,vStateIndex(iTime));
        fB = mBondPrime(ibA,ikA+1,vStateIndex(iTime));
        fC = mBondPrime(ibA+1,ikA,vStateIndex(iTime));
        fD = mBondPrime(ibA+1,ikA+1,vStateIndex(iTime));

        simBp(iTime,1) = fBiLinearInterpolation(kA, kB, bA, bC, fA, fB, fC, fD, kX, bX);
        
        fA = mL(ibA,ikA,vStateIndex(iTime));
        fB = mL(ibA,ikA+1,vStateIndex(iTime));
        fC = mL(ibA+1,ikA,vStateIndex(iTime));
        fD = mL(ibA+1,ikA+1,vStateIndex(iTime));

        simL(iTime,1) = fBiLinearInterpolation(kA, kB, bA, bC, fA, fB, fC, fD, kX, bX);
        
        fA = mV(ibA,ikA,vStateIndex(iTime));
        fB = mV(ibA,ikA+1,vStateIndex(iTime));
        fC = mV(ibA+1,ikA,vStateIndex(iTime));
        fD = mV(ibA+1,ikA+1,vStateIndex(iTime));

        simV(iTime,1) = fBiLinearInterpolation(kA, kB, bA, bC, fA, fB, fC, fD, kX, bX); 
        
        fA = mMu(ibA,ikA,vStateIndex(iTime));
        fB = mMu(ibA,ikA+1,vStateIndex(iTime));
        fC = mMu(ibA+1,ikA,vStateIndex(iTime));
        fD = mMu(ibA+1,ikA+1,vStateIndex(iTime));

        simMu(iTime,1) = fBiLinearInterpolation(kA, kB, bA, bC, fA, fB, fC, fD, kX, bX); 
        
        fA = mIdBind(ibA,ikA,vStateIndex(iTime));
        fB = mIdBind(ibA,ikA+1,vStateIndex(iTime));
        fC = mIdBind(ibA+1,ikA,vStateIndex(iTime));
        fD = mIdBind(ibA+1,ikA+1,vStateIndex(iTime));

        simIdBind(iTime,1) = fBiLinearInterpolation(kA, kB, bA, bC, fA, fB, fC, fD, kX, bX); 
        % Interpolation Procedure Ends
        
        simW(iTime,1)   = simL(iTime,1)^(pOmega-1)*(1+pTaxCons);
        simTFP(iTime,1) = vProdGrid(vStateIndex(iTime));
        simP(iTime,1)   = vPriceGrid(vStateIndex(iTime));
        simR(iTime,1)   = vIntRateGrid(vStateIndex(iTime)) + 1;
        simQb(iTime,1)  = 1/simR(iTime,1);
        simGDP(iTime,1) = vProdGrid(vStateIndex(iTime))*nProd*simKp(iTime-1,1)^pGamma*simL(iTime,1)^pAlpha*simV(iTime,1)^pEta  - simP(iTime,1)*simV(iTime,1);
 
        simCons(iTime,1) = (-simKp(iTime,1) + (1-pDelta)*simKp(iTime-1,1) - pAdjC/2*(simKp(iTime,1)-simKp(iTime-1,1))^2/simKp(iTime-1,1) +...
            simGDP(iTime,1) - pPhi*(simR(iTime,1)-1)*...
            (simW(iTime,1)*simL(iTime,1) + simP(iTime,1)*simV(iTime,1)) - simQb(iTime,1)*simBp(iTime,1) + simBp(iTime-1,1)) / (1+pTaxCons);
        
        simNX(iTime,1) = -simBp(iTime-1,1) + simBp(iTime,1)/(1+vIntRateGrid(vStateIndex(iTime))) + vIntRateGrid(vStateIndex(iTime))*pPhi*(simW(iTime,1)*simL(iTime,1) + simP(iTime,1)*simV(iTime,1)) ;
        
        simInv(iTime,1) = simKp(iTime,1) - (1-pDelta)*simKp(iTime-1,1) + pAdjC/2*( simKp(iTime,1) - simKp(iTime-1,1) )^2/simKp(iTime-1,1);
        simB_Y(iTime,1) = simBp(iTime-1,1) / simGDP(iTime,1);
        
        simWC(iTime,1)  = pPhi*(simW(iTime,1)*simL(iTime,1) + simP(iTime,1)*simV(iTime,1));
        simLev(iTime,1) = (simQb(iTime,1)*simBp(iTime,1) - pPhi*simR(iTime,1)*(simW(iTime,1)*simL(iTime,1) + simP(iTime,1)*simV(iTime,1)))/(simQK(iTime,1)*simKp(iTime,1));
        
        [~,nIdCapital] = min(abs(simKp(iTime-1) - vCapitalGrid));
        [~,nIdBond]    = min(abs(simBp(iTime-1) - vBondGrid)); 
        
        simCCBind(iTime,1) = mIdBind(nIdBond,nIdCapital,vStateIndex(iTime));
        
        if simIdBind(iTime,1) > 0.00001
            simCCBindInter(iTime,1) = 1;
        end

        
    end
    
    simNX_Y(iTime,1) = simNX(iTime,1) / simGDP(iTime,1);
    
end
                    
% ID of a SS event
simSS      = zeros(nTime,1);

simLogGDP = log(simGDP);
simLogC = log(simCons);
simLogI = log(simInv);
simLogQK = log(simQK);
simLogBp = log(simBp);

[simLogGDP_T, simLogGDP_C] = hpfilter(simLogGDP,100);
simLogGDP_C2 = simLogGDP_C + simLogGDP_T;
[simNX_Y_T, simNX_Y_C] = hpfilter(simNX_Y,100);
simNX_Y_C2 = simNX_Y_C + simNX_Y_T;

[simLogC_T, simLogC_C] = hpfilter(simLogC,100);
[simLogI_T, simLogI_C] = hpfilter(simLogI,100);
[simLogTFP_T, simLogTFP_C] = hpfilter(simTFP,100);
[simLogR_T, simLogR_C] = hpfilter(simR,100);
[simLogP_T, simLogP_C] = hpfilter(simP,100);

simSS(simLogGDP_C2 < simLogGDP_T - std(simLogGDP_T(nCut+1:end)) & simNX_Y_C2 > simNX_Y_T + std(simNX_Y_T(nCut+1:end)) & simCCBind > 0 ) = 1;

save simFiPIt_SS.mat

% Event Plot
clear all
close all
clc

load simFiPIt_SS.mat 

simCCBind_SS = simCCBind;
simSS_SS = simSS;

simGDP_SS = simGDP;
simCons_SS = simCons;
simInv_SS = simInv;
simNX_Y_SS = simNX_Y;
simQK_SS = simQK;
simBp_SS = simBp;
simKp_SS = simKp;
simTFP_SS = simTFP;
simR_SS = simR;
simP_SS = simP;
vStateIndex_SS = vStateIndex';

nMeanC_SS = nMeanC;
nMeanGDP_SS = nMeanGDP;
nMeanI_SS = nMeanI;
nMeanQK_SS = nMeanQK;
nMeanB_SS = nMeanB;

tNamePlot = 'EventStudySS_mean.pdf';
simSSused = simSS_SS;

id = 1;
for iShock=nCut:nTime-6
    if simSSused(iShock+3) == 1
        Shock_mat(1,id) = vStateIndex_SS(iShock,1);
        Shock_mat(2,id) = vStateIndex_SS(iShock+1,1);
        Shock_mat(3,id) = vStateIndex_SS(iShock+2,1);
        Shock_mat(4,id) = vStateIndex_SS(iShock+3,1);
        Shock_mat(5,id) = vStateIndex_SS(iShock+4,1);
        Shock_mat(6,id) = vStateIndex_SS(iShock+5,1);
        Shock_mat(7,id) = vStateIndex_SS(iShock+6,1);
        
        GDP1_mat(1,id) = simLogGDP_C(iShock,1);
        GDP1_mat(2,id) = simLogGDP_C(iShock+1,1);
        GDP1_mat(3,id) = simLogGDP_C(iShock+2,1);
        GDP1_mat(4,id) = simLogGDP_C(iShock+3,1);
        GDP1_mat(5,id) = simLogGDP_C(iShock+4,1);
        GDP1_mat(6,id) = simLogGDP_C(iShock+5,1);
        GDP1_mat(7,id) = simLogGDP_C(iShock+6,1);
        
        Cons1_mat(1,id) = simLogC_C(iShock,1);
        Cons1_mat(2,id) = simLogC_C(iShock+1,1);
        Cons1_mat(3,id) = simLogC_C(iShock+2,1);
        Cons1_mat(4,id) = simLogC_C(iShock+3,1);
        Cons1_mat(5,id) = simLogC_C(iShock+4,1);
        Cons1_mat(6,id) = simLogC_C(iShock+5,1);
        Cons1_mat(7,id) = simLogC_C(iShock+6,1);
        
        Inv1_mat(1,id) = simLogI_C(iShock,1);
        Inv1_mat(2,id) = simLogI_C(iShock+1,1);
        Inv1_mat(3,id) = simLogI_C(iShock+2,1);
        Inv1_mat(4,id) = simLogI_C(iShock+3,1);
        Inv1_mat(5,id) = simLogI_C(iShock+4,1);
        Inv1_mat(6,id) = simLogI_C(iShock+5,1);
        Inv1_mat(7,id) = simLogI_C(iShock+6,1);
        
        NX_Y1_mat(1,id) = simNX_Y_C(iShock,1);
        NX_Y1_mat(2,id) = simNX_Y_C(iShock+1,1);
        NX_Y1_mat(3,id) = simNX_Y_C(iShock+2,1);
        NX_Y1_mat(4,id) = simNX_Y_C(iShock+3,1);
        NX_Y1_mat(5,id) = simNX_Y_C(iShock+4,1);
        NX_Y1_mat(6,id) = simNX_Y_C(iShock+5,1);
        NX_Y1_mat(7,id) = simNX_Y_C(iShock+6,1);
        
        QK1_mat(1,id) = simQK_SS(iShock,1);
        QK1_mat(2,id) = simQK_SS(iShock+1,1);
        QK1_mat(3,id) = simQK_SS(iShock+2,1);
        QK1_mat(4,id) = simQK_SS(iShock+3,1);
        QK1_mat(5,id) = simQK_SS(iShock+4,1);
        QK1_mat(6,id) = simQK_SS(iShock+5,1);
        QK1_mat(7,id) = simQK_SS(iShock+6,1);
        
        B1_mat(1,id) = simBp_SS(iShock-1,1);
        B1_mat(2,id) = simBp_SS(iShock+0,1);
        B1_mat(3,id) = simBp_SS(iShock+1,1);
        B1_mat(4,id) = simBp_SS(iShock+2,1);
        B1_mat(5,id) = simBp_SS(iShock+3,1);
        B1_mat(6,id) = simBp_SS(iShock+4,1);
        B1_mat(7,id) = simBp_SS(iShock+5,1);
        
        K1_mat(1,id) = simKp_SS(iShock-1,1);
        K1_mat(2,id) = simKp_SS(iShock+0,1);
        K1_mat(3,id) = simKp_SS(iShock+1,1);
        K1_mat(4,id) = simKp_SS(iShock+2,1);
        K1_mat(5,id) = simKp_SS(iShock+3,1);
        K1_mat(6,id) = simKp_SS(iShock+4,1);
        K1_mat(7,id) = simKp_SS(iShock+5,1);
        
        TFP1_mat(1,id) = simLogTFP_C(iShock,1);
        TFP1_mat(2,id) = simLogTFP_C(iShock+1,1);
        TFP1_mat(3,id) = simLogTFP_C(iShock+2,1);
        TFP1_mat(4,id) = simLogTFP_C(iShock+3,1);
        TFP1_mat(5,id) = simLogTFP_C(iShock+4,1);
        TFP1_mat(6,id) = simLogTFP_C(iShock+5,1);
        TFP1_mat(7,id) = simLogTFP_C(iShock+6,1);
        
        P1_mat(1,id) = simLogP_C(iShock,1);
        P1_mat(2,id) = simLogP_C(iShock+1,1);
        P1_mat(3,id) = simLogP_C(iShock+2,1);
        P1_mat(4,id) = simLogP_C(iShock+3,1);
        P1_mat(5,id) = simLogP_C(iShock+4,1);
        P1_mat(6,id) = simLogP_C(iShock+5,1);
        P1_mat(7,id) = simLogP_C(iShock+6,1);
        
        R1_mat(1,id) = simLogR_C(iShock,1);
        R1_mat(2,id) = simLogR_C(iShock+1,1);
        R1_mat(3,id) = simLogR_C(iShock+2,1);
        R1_mat(4,id) = simLogR_C(iShock+3,1);
        R1_mat(5,id) = simLogR_C(iShock+4,1);
        R1_mat(6,id) = simLogR_C(iShock+5,1);
        R1_mat(7,id) = simLogR_C(iShock+6,1);
        
        id = id + 1;
        
    end
end

[nPeriod, nSS] = size(Shock_mat);

% Only SS lines

image=subplot(2,3,1);
x1 = mean(GDP1_mat,2);
plot(-3:3,mean(GDP1_mat,2),'LineWidth',2.5)
hold on
plot(-3:3,zeros(size(GDP1_mat)),'-black')
xlabel('T: Time Horizon')
title('GDP');    

image=subplot(2,3,2);
x1 = mean(Cons1_mat,2);
plot(-3:3,mean(Cons1_mat,2),'LineWidth',2.5)
hold on
plot(-3:3,zeros(size(GDP1_mat)),'-black')
xlabel('T: Time Horizon')
title('Private Consumption'); 

image=subplot(2,3,3);
x1 = mean(Inv1_mat,2);
plot(-3:3,mean(Inv1_mat,2),'LineWidth',2.5)
hold on
plot(-3:3,zeros(size(GDP1_mat)),'-black')
xlabel('T: Time Horizon')
title('Investment'); 

image=subplot(2,3,4);
x1 = mean(NX_Y1_mat,2);
plot(-3:3,mean(NX_Y1_mat,2),'LineWidth',2.5)
hold on
plot(-3:3,zeros(size(GDP1_mat)),'-black')
xlabel('T: Time Horizon')
title('Net Exports - GDP ratio');

image=subplot(2,3,5);
x1 = mean(QK1_mat,2);
plot(-3:3,mean(QK1_mat,2),'LineWidth',2.5)
hold on
plot(-3:3,ones(size(GDP1_mat)),'-black')
xlabel('T: Time Horizon')
title('Tobin Q');

image=subplot(2,3,6);
x1 = mean(TFP1_mat,2);
plot(-3:3,mean(TFP1_mat,2),'-',-3:3,mean(R1_mat,2),'--',-3:3,mean(P1_mat,2),':','LineWidth',2.5)
hold on
plot(-3:3,zeros(size(GDP1_mat)),'-black')
xlabel('T: Time Horizon')
title('TFP (solid), Int Rate (dashed), Price Input (dotted)');


set(gcf, 'PaperPosition', [0 0 10 6]); 
set(gcf, 'PaperSize', [10 6]); 
saveas(image, tNamePlot);

