%% FiPIt: A Simple, Fast Global Method for Solving Models with Two
%% Endogenous States & Occasionally Binding Constraints
%% Mendoza & Villalvazo 2018
% Code for Computing Sudden Stops Prob. and Amplification Coefficients
% (C.) Enrique G. Mendoza & Sergio Villalvazo, 2018
%% AMPLIFICATION TABLE

clear all
close all
clc

tMyDir      = pwd;
tIdcs       = strfind(tMyDir,'\');
tMyDirUp    = tMyDir(1:tIdcs(end)-1);
tMFilesPath = [tMyDirUp, '\MFiles\'];
addpath(tMFilesPath);

load 'solFiPIt_SS.mat'

mBpSS = mBondPrime;
mKpSS = mCapitalPrime;
mQKSS = mPriceK;
mCSS = mC;
mISS = mInv;
mLSS= mL;
mVSS= mV;
mGDPSS = mGDP;
mNX_GDPSS = mNX_GDP;
mB_GDPSS = mB_GDP;
mKp_GDPSS = mCapitalPrime./mGDP;
mLevSS = mLev;
mWCSS= mWC;

mBp_GDPSS = mBondPrime./mGDP;

mErgDistSS = mErgDist;
mIdBindSS = mIdBind;


clearvars -except mBpSS mKpSS mQKSS mCSS mISS mLSS mVSS mGDPSS ...
    mNX_GDPSS mBp_GDPSS mB_GDPSS mKp_GDPSS mLevSS mWCSS mErgDistSS mIdBindSS pBondMinSSID

 load 'solFiPIt_RBC.mat'

mBp = mBondPrime(pBondMinSSID:end,:,:);
mKp = mCapitalPrime(pBondMinSSID:end,:,:);
mQK = mPriceK(pBondMinSSID:end,:,:);
mC = mC(pBondMinSSID:end,:,:);
mI = mInv(pBondMinSSID:end,:,:);
mL = mL(pBondMinSSID:end,:,:);
mV = mV(pBondMinSSID:end,:,:);
mNX_GDP = mNX_GDP(pBondMinSSID:end,:,:);
mB_GDP = mB_GDP(pBondMinSSID:end,:,:);
mLev = mLev(pBondMinSSID:end,:,:);
mWC = mWC(pBondMinSSID:end,:,:);
mKp_GDP = mCapitalPrime(pBondMinSSID:end,:,:)./mGDP(pBondMinSSID:end,:,:);
mBp_GDP = mBondPrime(pBondMinSSID:end,:,:)./mGDP(pBondMinSSID:end,:,:);
mErgDist = mErgDist(pBondMinSSID:end,:,:);
mGDP = mGDP(pBondMinSSID:end,:,:);

clearvars -except mBpSS mKpSS mQKSS mCSS mISS mLSS mVSS mGDPSS ...
    mNX_GDPSS mBp_GDPSS mB_GDPSS mKp_GDPSS mLevSS mWCSS mErgDistSS mIdBindSS pBondMinSSID ...
    mBp mKp mQK mC mI mL mV mGDP mNX_GDP mBp_GDP mB_GDP mKp_GDP mLev mWC mErgDist ...
    nBondGrid nCapitalGrid nShockGrid


nBondGrid = nBondGrid - pBondMinSSID + 1;


nGDP_SSmean  = 0;
nGDP_NSSmean = 0;
nGDP_SSdiff  = 0;
mGDP_SSdiff  = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nGDP_NSSdiff = 0;
mGDP_NSSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nGDP_RBCmean = sum(sum(sum(mGDP.*mErgDist)));

nC_SSmean  = 0;
nC_NSSmean = 0;
nC_SSdiff  = 0;
mC_SSdiff  = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nC_NSSdiff = 0;
mC_NSSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nC_RBCmean = sum(sum(sum(mC.*mErgDist)));

nI_SSmean  = 0;
nI_NSSmean = 0;
nI_SSdiff  = 0;
mI_SSdiff  = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nI_NSSdiff = 0;
mI_NSSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nI_RBCmean = sum(sum(sum(mI.*mErgDist)));

nQK_SSmean = 0;
nQK_NSSmean = 0;
nQK_SSdiff = 0;
mQK_SSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nQK_NSSdiff = 0;
mQK_NSSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nQK_RBCmean = sum(sum(sum(mQK.*mErgDist)));

nNX_GDP_SSmean = 0;
nNX_GDP_NSSmean = 0;
nNX_GDP_SSdiff = 0;
mNX_GDP_SSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nNX_GDP_NSSdiff = 0;
mNX_GDP_NSSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nNX_GDP_RBCmean = sum(sum(sum(mNX_GDP.*mErgDist)));

nBp_GDP_SSmean = 0;
nBp_GDP_NSSmean = 0;
nBp_GDP_SSdiff = 0;
mBp_GDP_SSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nBp_GDP_NSSdiff = 0;
mBp_GDP_NSSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nBp_GDP_RBCmean = sum(sum(sum(mBp_GDP.*mErgDist)));

nB_GDP_SSmean = 0;
nB_GDP_NSSmean = 0;
nB_GDP_SSdiff = 0;
mB_GDP_SSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nB_GDP_NSSdiff = 0;
mB_GDP_NSSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nB_GDP_RBCmean = sum(sum(sum(mB_GDP.*mErgDist)));

nKp_GDP_SSmean = 0;
nKp_GDP_NSSmean = 0;
nKp_GDP_SSdiff = 0;
mKp_GDP_SSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nKp_GDP_NSSdiff = 0;
mKp_GDP_NSSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nKp_GDP_RBCmean = sum(sum(sum(mKp_GDP.*mErgDist)));

nBp_SSmean = 0;
nBp_NSSmean = 0;
nBp_SSdiff = 0;
mBp_SSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nBp_NSSdiff = 0;
mBp_NSSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nBp_RBCmean = sum(sum(sum(mBp.*mErgDist)));

nLev_SSmean = 0;
nLev_NSSmean = 0;
nLev_SSdiff = 0;
mLev_SSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nLev_NSSdiff = 0;
mLev_NSSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nLev_RBCmean = sum(sum(sum(mLev.*mErgDist)));

nL_SSmean = 0;
nL_NSSmean = 0;
nL_SSdiff = 0;
mL_SSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nL_NSSdiff = 0;
mL_NSSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nL_RBCmean = sum(sum(sum(mL.*mErgDist)));

nV_SSmean = 0;
nV_NSSmean = 0;
nV_SSdiff = 0;
mV_SSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nV_NSSdiff = 0;
mV_NSSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nV_RBCmean = sum(sum(sum(mV.*mErgDist)));

nWC_SSmean = 0;
nWC_NSSmean = 0;
nWC_SSdiff = 0;
mWC_SSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nWC_NSSdiff = 0;
mWC_NSSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nWC_RBCmean = sum(sum(sum(mWC.*mErgDist)));

nKp_SSmean = 0;
nKp_NSSmean = 0;
nKp_SSdiff = 0;
mKp_SSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nKp_NSSdiff = 0;
mKp_NSSdiff = zeros(nBondGrid, nCapitalGrid, nShockGrid);
nKp_RBCmean = sum(sum(sum(mKp.*mErgDist)));

mProbSS = zeros(nBondGrid, nCapitalGrid, nShockGrid);
mProbNSS = zeros(nBondGrid, nCapitalGrid, nShockGrid);
mProbSSExt = zeros(nBondGrid, nCapitalGrid, nShockGrid);

for iBond = 1:nBondGrid
    for iCapital = 1:nCapitalGrid
        for iShock = 1:nShockGrid
            if mErgDistSS(iBond,iCapital,iShock) < 0.000001
                mErgDistSS(iBond,iCapital,iShock) = 0;
            end
        end
    end
end

mIdBindExt = mIdBindSS;

for iBond = 1:nBondGrid-1
    for iCapital = 1:nCapitalGrid
        for iShock = 1:nShockGrid
            if mIdBindSS(iBond,iCapital,iShock) == 1 && mIdBindSS(iBond+1,iCapital,iShock) == 0
                if sum(mErgDistSS(:, iCapital, iShock)) > 0                  
                    mIdBindExt(iBond + 1, iCapital, iShock) = sum(mErgDistSS(1:iBond, iCapital, iShock))/sum(mErgDistSS(:, iCapital, iShock));
                end    
            end
        end
    end
end


for iBond = 1:nBondGrid
    for iCapital = 1:nCapitalGrid
        for iShock = 1:nShockGrid
            if mIdBindSS(iBond,iCapital,iShock) == 1 && ...
                    mNX_GDPSS(iBond,iCapital,iShock) - mNX_GDP(iBond,iCapital,iShock) >= 0.02
               mProbSS(iBond,iCapital,iShock) = mErgDistSS(iBond,iCapital,iShock);
            else
               mProbNSS(iBond,iCapital,iShock) = mErgDistSS(iBond,iCapital,iShock);
            end
        end
    end
end

for iBond = 1:nBondGrid
    for iCapital = 1:nCapitalGrid
        for iShock = 1:nShockGrid
            if mIdBindExt(iBond,iCapital,iShock) > 0 && ...
                    mNX_GDPSS(iBond,iCapital,iShock) - mNX_GDP(iBond,iCapital,iShock) >= 0.02
               mProbSSExt(iBond,iCapital,iShock) = mIdBindExt(iBond,iCapital,iShock)*mErgDistSS(iBond,iCapital,iShock);
            end
        end
    end
end

nProbSS = sum(sum(sum(mProbSS)))*100  ;
nProbSSExt = sum(sum(sum(mProbSSExt)))*100  ;

% Normalize to 1
if nProbSS > 0
    mProbSS = mProbSS./sum(sum(sum(mProbSS)));
    mProbNSS = mProbNSS./sum(sum(sum(mProbNSS)));
end

for iBond = 1:nBondGrid
    for iCapital = 1:nCapitalGrid
        for iShock = 1:nShockGrid
            
            if mIdBindSS(iBond,iCapital,iShock) == 1 && ...
                    mNX_GDPSS(iBond,iCapital,iShock) - mNX_GDP(iBond,iCapital,iShock) >= 0.02
                
                mGDP_SSdiff(iBond,iCapital,iShock) = mGDPSS(iBond,iCapital,iShock) - mGDP(iBond,iCapital,iShock);
                nGDP_SSmean = nGDP_SSmean + mGDPSS(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
                
                mC_SSdiff(iBond,iCapital,iShock) = mCSS(iBond,iCapital,iShock) - mC(iBond,iCapital,iShock);
                nC_SSmean = nC_SSmean + mCSS(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
                
                mI_SSdiff(iBond,iCapital,iShock) = mISS(iBond,iCapital,iShock) - mI(iBond,iCapital,iShock);
                nI_SSmean = nI_SSmean + mISS(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
                
                mQK_SSdiff(iBond,iCapital,iShock) = mQKSS(iBond,iCapital,iShock) - mQK(iBond,iCapital,iShock);
                nQK_SSmean = nQK_SSmean + mQKSS(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
                
                mNX_GDP_SSdiff(iBond,iCapital,iShock) = mNX_GDPSS(iBond,iCapital,iShock) - mNX_GDP(iBond,iCapital,iShock);
                nNX_GDP_SSmean = nNX_GDP_SSmean + mNX_GDPSS(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
                
                mBp_GDP_SSdiff(iBond,iCapital,iShock) = mBp_GDPSS(iBond,iCapital,iShock) - mBp_GDP(iBond,iCapital,iShock);
                nBp_GDP_SSmean = nBp_GDP_SSmean + mBp_GDPSS(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
                
                mB_GDP_SSdiff(iBond,iCapital,iShock) = mB_GDPSS(iBond,iCapital,iShock) - mB_GDP(iBond,iCapital,iShock);
                nB_GDP_SSmean = nB_GDP_SSmean + mB_GDPSS(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
                
                mKp_GDP_SSdiff(iBond,iCapital,iShock) = mKp_GDPSS(iBond,iCapital,iShock) - mKp_GDP(iBond,iCapital,iShock);
                nKp_GDP_SSmean = nKp_GDP_SSmean + mKp_GDPSS(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
                
                mBp_SSdiff(iBond,iCapital,iShock) = mBpSS(iBond,iCapital,iShock) - mBp(iBond,iCapital,iShock);
                nBp_SSmean = nBp_SSmean + mBpSS(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
                
                mLev_SSdiff(iBond,iCapital,iShock) = mLevSS(iBond,iCapital,iShock) - mLev(iBond,iCapital,iShock);
                nLev_SSmean = nLev_SSmean + mLevSS(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
                
                mL_SSdiff(iBond,iCapital,iShock) = mLSS(iBond,iCapital,iShock) - mL(iBond,iCapital,iShock);
                nL_SSmean = nL_SSmean + mLSS(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
                
                mV_SSdiff(iBond,iCapital,iShock) = mVSS(iBond,iCapital,iShock) - mV(iBond,iCapital,iShock);
                nV_SSmean = nV_SSmean + mVSS(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
                
                mWC_SSdiff(iBond,iCapital,iShock) = mWCSS(iBond,iCapital,iShock) - mWC(iBond,iCapital,iShock);
                nWC_SSmean = nWC_SSmean + mWCSS(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
                
                mKp_SSdiff(iBond,iCapital,iShock) = mKpSS(iBond,iCapital,iShock) - mKp(iBond,iCapital,iShock);
                nKp_SSmean = nKp_SSmean + mKpSS(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
                
                
            else
                
                mGDP_NSSdiff(iBond,iCapital,iShock) = mGDPSS(iBond,iCapital,iShock) - mGDP(iBond,iCapital,iShock);
                nGDP_NSSmean = nGDP_NSSmean + mGDP(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
                
                mC_NSSdiff(iBond,iCapital,iShock) = mCSS(iBond,iCapital,iShock) - mC(iBond,iCapital,iShock);
                nC_NSSmean = nC_NSSmean + mC(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
                
                mI_NSSdiff(iBond,iCapital,iShock) = mISS(iBond,iCapital,iShock) - mI(iBond,iCapital,iShock);
                nI_NSSmean = nI_NSSmean + mI(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
                
                mQK_NSSdiff(iBond,iCapital,iShock) = mQKSS(iBond,iCapital,iShock) - mQK(iBond,iCapital,iShock);
                nQK_NSSmean = nQK_NSSmean + mQK(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
                
                mNX_GDP_NSSdiff(iBond,iCapital,iShock) = mNX_GDPSS(iBond,iCapital,iShock) - mNX_GDP(iBond,iCapital,iShock);
                nNX_GDP_NSSmean = nNX_GDP_NSSmean + mNX_GDP(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
                
                mBp_GDP_NSSdiff(iBond,iCapital,iShock) = mBp_GDPSS(iBond,iCapital,iShock) - mBp_GDP(iBond,iCapital,iShock);
                nBp_GDP_NSSmean = nBp_GDP_NSSmean + mBp_GDP(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
                
                mKp_GDP_NSSdiff(iBond,iCapital,iShock) = mKp_GDPSS(iBond,iCapital,iShock) - mKp_GDP(iBond,iCapital,iShock);
                nKp_GDP_NSSmean = nKp_GDP_NSSmean + mKp_GDP(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
                
                mBp_NSSdiff(iBond,iCapital,iShock) = mBpSS(iBond,iCapital,iShock) - mBp(iBond,iCapital,iShock);
                nBp_NSSmean = nBp_NSSmean + mBp(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
                
                mLev_NSSdiff(iBond,iCapital,iShock) = mLevSS(iBond,iCapital,iShock) - mLev(iBond,iCapital,iShock);
                nLev_NSSmean = nLev_NSSmean + mLev(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
                
                mL_NSSdiff(iBond,iCapital,iShock) = mLSS(iBond,iCapital,iShock) - mL(iBond,iCapital,iShock);
                nL_NSSmean = nL_NSSmean + mL(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
                
                mV_NSSdiff(iBond,iCapital,iShock) = mVSS(iBond,iCapital,iShock) - mV(iBond,iCapital,iShock);
                nV_NSSmean = nV_NSSmean + mV(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
                
                mWC_NSSdiff(iBond,iCapital,iShock) = mWCSS(iBond,iCapital,iShock) - mWC(iBond,iCapital,iShock);
                nWC_NSSmean = nWC_NSSmean + mWC(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
                
                mKp_NSSdiff(iBond,iCapital,iShock) = mKpSS(iBond,iCapital,iShock) - mKp(iBond,iCapital,iShock);
                nKp_NSSmean = nKp_NSSmean + mKp(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
                                
            end

            nGDP_SSdiff = nGDP_SSdiff + mGDP_SSdiff(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
            nGDP_NSSdiff = nGDP_NSSdiff + mGDP_NSSdiff(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
            
            nC_SSdiff = nC_SSdiff + mC_SSdiff(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
            nC_NSSdiff = nC_NSSdiff + mC_NSSdiff(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
            
            nI_SSdiff = nI_SSdiff + mI_SSdiff(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
            nI_NSSdiff = nI_NSSdiff + mI_NSSdiff(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
            
            nQK_SSdiff = nQK_SSdiff + mQK_SSdiff(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
            nQK_NSSdiff = nQK_NSSdiff + mQK_NSSdiff(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
            
            nNX_GDP_SSdiff = nNX_GDP_SSdiff + mNX_GDP_SSdiff(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
            nNX_GDP_NSSdiff = nNX_GDP_NSSdiff + mNX_GDP_NSSdiff(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
            
            nBp_GDP_SSdiff = nBp_GDP_SSdiff + mBp_GDP_SSdiff(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
            nBp_GDP_NSSdiff = nBp_GDP_NSSdiff + mBp_GDP_NSSdiff(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
            
            nKp_GDP_SSdiff = nKp_GDP_SSdiff + mKp_GDP_SSdiff(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
            nKp_GDP_NSSdiff = nKp_GDP_NSSdiff + mKp_GDP_NSSdiff(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
            
            nBp_SSdiff = nBp_SSdiff + mBp_SSdiff(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
            nBp_NSSdiff = nBp_NSSdiff + mBp_NSSdiff(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
            
            nLev_SSdiff = nLev_SSdiff + mLev_SSdiff(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
            nLev_NSSdiff = nLev_NSSdiff + mLev_NSSdiff(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
            
            nL_SSdiff = nL_SSdiff + mL_SSdiff(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
            nL_NSSdiff = nL_NSSdiff + mL_NSSdiff(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
            
            nV_SSdiff = nV_SSdiff + mV_SSdiff(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
            nV_NSSdiff = nV_NSSdiff + mV_NSSdiff(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
            
            nWC_SSdiff = nWC_SSdiff + mWC_SSdiff(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
            nWC_NSSdiff = nWC_NSSdiff + mWC_NSSdiff(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
            
            nKp_SSdiff = nKp_SSdiff + mKp_SSdiff(iBond,iCapital,iShock) * mProbSS(iBond,iCapital,iShock);
            nKp_NSSdiff = nKp_NSSdiff + mKp_NSSdiff(iBond,iCapital,iShock) * mProbNSS(iBond,iCapital,iShock);
            
        end
    end
end


fprintf('\n')
fprintf('GDP = %.3f , %.3f \n',nGDP_SSdiff/nGDP_RBCmean*100,nGDP_NSSdiff/nGDP_RBCmean*100 )
fprintf('c = %.3f , %.3f \n',nC_SSdiff/nC_RBCmean*100,nC_NSSdiff/nC_RBCmean*100 )
fprintf('I = %.3f , %.3f \n',nI_SSdiff/nI_RBCmean*100,nI_NSSdiff/nI_RBCmean*100 )
fprintf('QK = %.3f , %.3f \n',nQK_SSdiff/nQK_RBCmean*100,nQK_NSSdiff/nQK_RBCmean*100 )
fprintf('NX_GDP = %.3f , %.3f \n',nNX_GDP_SSdiff*100,nNX_GDP_NSSdiff*100 )
fprintf('Bp_GDP = %.3f , %.3f \n',nBp_GDP_SSdiff*100,nBp_GDP_NSSdiff*100 )
fprintf('Kp_GDP = %.3f , %.3f \n',nKp_GDP_SSdiff*100,nKp_GDP_NSSdiff*100 )
fprintf('Lev = %.3f , %.3f \n',nLev_SSdiff*100,nLev_NSSdiff*100 )
fprintf('L = %.3f , %.3f \n',nL_SSdiff/nL_RBCmean*100,nL_NSSdiff/nL_RBCmean*100 )
fprintf('V = %.3f , %.3f \n',nV_SSdiff/nV_RBCmean*100,nV_NSSdiff/nV_RBCmean*100 )
fprintf('WC = %.3f , %.3f \n',nWC_SSdiff/nWC_RBCmean*100,nWC_NSSdiff/nWC_RBCmean*100 )
fprintf('\n')
fprintf('P(S.S.) = %.2f  \n',nProbSS )

