% 
%
% Function: fFiPIt_EulerError
% Calculates the Euler Errors 
% (C.) Enrique G. Mendoza & Sergio Villalvazo, 2018
function [Y] = fFiPIt_EulerError(x,pKappa,pTaxCons,pEta,pAdjC,pPhi, pDelta, pBeta,pSigma,mTran,pAlpha,pGamma,pOmega,nProd,iBond,iCapital,iShock, nShockGrid,vPriceGrid,vProdGrid,vBondGrid,vCapitalGrid,vIntRateGrid,mCapitalPrimeGuess,mPolicyBondPrimeGuess,mMuHatGuess,MuHat,MuBond,mC,mL,mV,mPriceKGuess)
        
        % Store the size of the bond and capital grids
        nB = size(vBondGrid,1);
        nK = size(vCapitalGrid,1);
        
        % Store the values that will be interpolated
        bp = x(1);
        kp = x(2);

        % Initialize the Expectation values
        EE1 = 0;
        EE2 = 0;
        
        % This FOR loop is to obtain the expected value
        for isp = 1:nShockGrid
            
            % Bilinear interpolation to get k'', b'' and muHat'
            kX = kp;
            bX = bp;  
            
            % Here we locate the grid points below and above the
            % conjectured policies
            ikA = 0;
            iAbove = 0;
            while iAbove == 0 && ikA < nK
               ikA = ikA + 1;
               if kp < vCapitalGrid(ikA)
                   iAbove = 1;
               end
            end
            if iAbove == 1 && ikA > 1
               ikA = ikA - 1;
            elseif ikA == nK
               ikA = nK - 1;
            end

            ibA = 0;
            iAbove = 0;
            while iAbove == 0 && ibA < nB
               ibA = ibA + 1;
               if bp < vBondGrid(ibA)
                   iAbove = 1;
               end
            end
            if iAbove == 1 && ibA > 1
               ibA = ibA - 1;
            elseif ibA == nB
               ibA = nB - 1;
            end
            
            % Obtain the gridpoints such that kA <= kp <= kB
            kA = vCapitalGrid(ikA);
            kB = vCapitalGrid(ikA+1);
            % Obtain the gridpoints such that bA <= bp <= bC
            bA = vBondGrid(ibA);
            bC = vBondGrid(ibA+1);
            
            % Interpolate k' to obtain k''
            fA = mCapitalPrimeGuess(ibA,ikA,isp);
            fB = mCapitalPrimeGuess(ibA,ikA+1,isp);
            fC = mCapitalPrimeGuess(ibA+1,ikA,isp);
            fD = mCapitalPrimeGuess(ibA+1,ikA+1,isp);
            
            kpp = fBiLinearInterpolation(kA, kB, bA, bC, fA, fB, fC, fD, kX, bX);
                             
            % Interpolate qk to obtain qk'
            fA = mPriceKGuess(ibA,ikA,isp);
            fB = mPriceKGuess(ibA,ikA+1,isp);
            fC = mPriceKGuess(ibA+1,ikA,isp);
            fD = mPriceKGuess(ibA+1,ikA+1,isp);
            
            qKp = fBiLinearInterpolation(kA, kB, bA, bC, fA, fB, fC, fD, kX, bX);
            
            % Interpolate v to obtain v'
            fA = mV(ibA,ikA,isp);
            fB = mV(ibA,ikA+1,isp);
            fC = mV(ibA+1,ikA,isp);
            fD = mV(ibA+1,ikA+1,isp);
            
            vp = fBiLinearInterpolation(kA, kB, bA, bC, fA, fB, fC, fD, kX, bX);
                       
            % Interpolate c to obtain c'
            fA = mC(ibA,ikA,isp);
            fB = mC(ibA,ikA+1,isp);
            fC = mC(ibA+1,ikA,isp);
            fD = mC(ibA+1,ikA+1,isp);
            
            cp = fBiLinearInterpolation(kA, kB, bA, bC, fA, fB, fC, fD, kX, bX);
            
            % Interpolate L to obtain L'
            fA = mL(ibA,ikA,isp);
            fB = mL(ibA,ikA+1,isp);
            fC = mL(ibA+1,ikA,isp);
            fD = mL(ibA+1,ikA+1,isp);
            
            Lp = fBiLinearInterpolation(kA, kB, bA, bC, fA, fB, fC, fD, kX, bX);
            % Interpoaltion ends
            
            % Obtain the expectation values
            Fkp = (pGamma*vProdGrid(isp)*nProd*kp^(pGamma-1)*Lp^pAlpha*vp^pEta...
                - pDelta + pAdjC/2*(kpp-kp)^2/(kp^2) + qKp );
            
            MgUp = (cp - (Lp^pOmega)/pOmega)^(-pSigma);
            
            EE1 = EE1 + mTran(iShock,isp)*MgUp;  
            EE2 = EE2 + mTran(iShock,isp)*MgUp * Fkp;
         
        end
        
        qk = mPriceKGuess(iBond,iCapital,iShock);
        L = mL(iBond,iCapital,iShock); 
        c = mC(iBond,iCapital,iShock);
        R  = vIntRateGrid(iShock) + 1;
        qb = 1/R;
        mu = MuHat*(c - L^pOmega/pOmega)^-pSigma / (1+pTaxCons);

        % Log10 Abs. Euler Errors
        Y(1) = log10(abs( 1 - ( ((pBeta*EE1 + qb*mu + MuBond)/qb)^(-1/pSigma) + (L^pOmega)/pOmega ) / c )); 
        Y(2) = log10(abs(1 - ( (pBeta*EE2/(qk*(1 - pKappa*MuHat)))^(-1/pSigma) + (L^pOmega)/pOmega ) / c ));

end
        
        
        
        