% 
%
% Function: fFiPIt_MuBond
% Calculates the multilpier of bond policy
% (C.) Enrique G. Mendoza & Sergio Villalvazo, 2018
function [Y] = fFiPIt_MuBond(pTaxCons,pEta,pAdjC,pPhi, pDelta, pBeta,pSigma,mTran,pAlpha,pGamma,pOmega,nProd,iBond,iCapital,iShock, nShockGrid,vPriceGrid,vProdGrid,vBondGrid,vCapitalGrid,vIntRateGrid,mCapitalPrime,mBondPrimeGuess,mMuHatGuess,mCGuess,mLGuess)
        
        % Store the size of the bond and capital grids
        nB = size(vBondGrid,1);
        nK = size(vCapitalGrid,1);
        
        % Store the values that will be interpolated
        bp = vBondGrid(1);
        kp = mCapitalPrime(iBond, iCapital, iShock);
    
        % Initialize the Expectation values
        EE1 = 0;
        
        % This FOR loop is to obtain the expected value
        for isp = 1:nShockGrid
            
            % Bilinear interpolation to get k'', b'' and muHat'
            kX = kp;
            bX = bp;          
            
            % Here we locate the grid points below and above the
            % conjectured policies
            ikA = 0;
            iAbove = 0;
            while iAbove == 0 && ikA < nK
               ikA = ikA + 1;
               if kp < vCapitalGrid(ikA)
                   iAbove = 1;
               end
            end
            if iAbove == 1 && ikA > 1
               ikA = ikA - 1;
            elseif ikA == nK
               ikA = nK - 1;
            end

            ibA = 0;
            iAbove = 0;
            while iAbove == 0 && ibA < nB
               ibA = ibA + 1;
               if bp < vBondGrid(ibA)
                   iAbove = 1;
               end
            end
            if iAbove == 1 && ibA > 1
               ibA = ibA - 1;
            elseif ibA == nB
               ibA = nB - 1;
            end
            
            % Obtain the gridpoints such that kA <= kp <= kB
            kA = vCapitalGrid(ikA);
            kB = vCapitalGrid(ikA+1);
            % Obtain the gridpoints such that bA <= bp <= bC
            bA = vBondGrid(ibA);
            bC = vBondGrid(ibA+1);
            
            % Interpolate c to obtain c'
            fA = mCGuess(ibA,ikA,isp);
            fB = mCGuess(ibA,ikA+1,isp);
            fC = mCGuess(ibA+1,ikA,isp);
            fD = mCGuess(ibA+1,ikA+1,isp);
            
            cp = fBiLinearInterpolation(kA, kB, bA, bC, fA, fB, fC, fD, kX, bX);
            
            % Interpolate L to obtain L'
            fA = mLGuess(ibA,ikA,isp);
            fB = mLGuess(ibA,ikA+1,isp);
            fC = mLGuess(ibA+1,ikA,isp);
            fD = mLGuess(ibA+1,ikA+1,isp);
            
            Lp = fBiLinearInterpolation(kA, kB, bA, bC, fA, fB, fC, fD, kX, bX);
            % Interpolation ends
                        
            MgUp = (cp - (Lp^pOmega)/pOmega)^(-pSigma);
            EE1 = EE1 + mTran(iShock,isp)*MgUp;  
            
         
        end
        
        c = mCGuess(iBond,iCapital,iShock);
        L = mLGuess(iBond,iCapital,iShock);
        R  = vIntRateGrid(iShock) + 1;
        
        qb = 1/R;
        
        muBond = (qb*(c - (L^pOmega)/pOmega)^(-pSigma) - pBeta*EE1)/(1+pTaxCons);
        
        Y(1) = muBond ; 

end
        
        
        
        