% 
%
% Function: fFiPIt_PriceK
% Uses Fix Point Iteration to obtain Price of Capital 
% (C.) Enrique G. Mendoza & Sergio Villalvazo, 2018
function [Y] = fFiPIt_PriceK(pKappa,pTaxCons,pEta,pAdjC,pPhi, pDelta, pBeta,pSigma,mTran,pAlpha,pGamma,pOmega,nProd,iBond,iCapital,iShock, nShockGrid,vPriceGrid,vProdGrid,vBondGrid,vCapitalGrid,vIntRateGrid,mCapitalPrimeGuess,mBondPrime,mPriceKGuessInner,mMuHat,mC,mL,mV)
        
        % Store the size of the bond and capital grids
        nB = size(vBondGrid,1);
        nK = size(vCapitalGrid,1);
        
        % Store the values that will be interpolated
        bp = mBondPrime(iBond, iCapital, iShock);
        kp = mCapitalPrimeGuess(iBond, iCapital, iShock);

        % Initialize the Expectation values
        EE2 = 0;
        
        % This FOR loop is to obtain the expected value
        for isp = 1:nShockGrid
            
            % Bilinear interpolation to get k'', b'', qk', muHat'
            kX = kp;
            bX = bp;     
            
            % Here we locate the grid points below and above the
            % conjectured policies
            ikA = 0;
            iAbove = 0;
            while iAbove == 0 && ikA < nK
               ikA = ikA + 1;
               if kp < vCapitalGrid(ikA)
                   iAbove = 1;
               end
            end
            if iAbove == 1 && ikA > 1
               ikA = ikA - 1;
            elseif ikA == nK
               ikA = nK - 1;
            end

            ibA = 0;
            iAbove = 0;
            while iAbove == 0 && ibA < nB
               ibA = ibA + 1;
               if bp < vBondGrid(ibA)
                   iAbove = 1;
               end
            end
            if iAbove == 1 && ibA > 1
               ibA = ibA - 1;
            elseif ibA == nB
               ibA = nB - 1;
            end
            
            % Obtain the gridpoints such that kA <= kp <= kB
            kA = vCapitalGrid(ikA);
            kB = vCapitalGrid(ikA+1);
            % Obtain the gridpoints such that bA <= bp <= bC
            bA = vBondGrid(ibA);
            bC = vBondGrid(ibA+1);
            
            % Interpolate k' to obtain k'' (k_t+2)
            fA = mCapitalPrimeGuess(ibA,ikA,isp);
            fB = mCapitalPrimeGuess(ibA,ikA+1,isp);
            fC = mCapitalPrimeGuess(ibA+1,ikA,isp);
            fD = mCapitalPrimeGuess(ibA+1,ikA+1,isp);
            
            kpp = fBiLinearInterpolation(kA, kB, bA, bC, fA, fB, fC, fD, kX, bX);
            
            % Interpolate qk to obtain qk' (qk_t+1)
            fA = mPriceKGuessInner(ibA,ikA,isp);
            fB = mPriceKGuessInner(ibA,ikA+1,isp);
            fC = mPriceKGuessInner(ibA+1,ikA,isp);
            fD = mPriceKGuessInner(ibA+1,ikA+1,isp);
            
            qKp = fBiLinearInterpolation(kA, kB, bA, bC, fA, fB, fC, fD, kX, bX);
            
            % Interpolate v to obtain v' (v_t+1)
            fA = mV(ibA,ikA,isp);
            fB = mV(ibA,ikA+1,isp);
            fC = mV(ibA+1,ikA,isp);
            fD = mV(ibA+1,ikA+1,isp);
            
            vp = fBiLinearInterpolation(kA, kB, bA, bC, fA, fB, fC, fD, kX, bX);
                       
            % Interpolate c to obtain c' (c_t+1)
            fA = mC(ibA,ikA,isp);
            fB = mC(ibA,ikA+1,isp);
            fC = mC(ibA+1,ikA,isp);
            fD = mC(ibA+1,ikA+1,isp);
            
            cp = fBiLinearInterpolation(kA, kB, bA, bC, fA, fB, fC, fD, kX, bX);
            
            % Interpolate L to obtain L' (L_t+1)
            fA = mL(ibA,ikA,isp);
            fB = mL(ibA,ikA+1,isp);
            fC = mL(ibA+1,ikA,isp);
            fD = mL(ibA+1,ikA+1,isp);
            
            Lp = fBiLinearInterpolation(kA, kB, bA, bC, fA, fB, fC, fD, kX, bX);
            % Interpoaltion ends
            
            Fkp = (pGamma*vProdGrid(isp)*nProd*kp^(pGamma-1)*Lp^pAlpha*vp^pEta...
                - pDelta + pAdjC/2*(kpp-kp)^2/(kp^2) + qKp );  %div._t+1 + qk_t+1 
            
            MgUp = (cp - (Lp^pOmega)/pOmega)^(-pSigma); %u'(t+1)
            
            EE2 = EE2 + mTran(iShock,isp)*MgUp * Fkp; %E[u'(t+1)(div_t+1+qk_t+1)]
         
        end
        
        MuHat = mMuHat(iBond,iCapital,iShock); %mu_t
        L = mL(iBond,iCapital,iShock); %L_t
        c = mC(iBond,iCapital,iShock); %c_t
        
        Y(1) = pBeta*EE2/((c  - (L^pOmega)/pOmega)^(-pSigma)*(1 - pKappa*MuHat)); %new qk function

end